@@ -1,15 +1,14 @@
 var indexSectionsWithContent =
 {
-  0: "_abcdefghilmnopqrstuvwy",
+  0: "<_abcdefghiklmnopqrstuvwy",
   1: "dltw",
-  2: "abcdefilmpstuw",
-  3: "_abcdefghilmpqrstuvw",
+  2: "abcdefilmprstuw",
+  3: "_abcdefghiklmpqrstuvw",
   4: "_deqrtwy",
-  5: "_fiptu",
+  5: "_fitu",
   6: "_",
-  7: "c",
-  8: "acdeu",
-  9: "abcdfhimprtu"
+  7: "<acdeu",
+  8: "abdfghimptu"
 };
 
 var indexSectionNames =
@@ -21,9 +20,8 @@ var indexSectionNames =
   4: "variables",
   5: "typedefs",
   6: "enums",
-  7: "defines",
-  8: "groups",
-  9: "pages"
+  7: "groups",
+  8: "pages"
 };
 
 var indexSectionLabels =
@@ -35,8 +33,7 @@ var indexSectionLabels =
   4: "Variables",
   5: "Typedefs",
   6: "Enumerations",
-  7: "Macros",
-  8: "Modules",
-  9: "Pages"
+  7: "Modules",
+  8: "Pages"
 };
 
